pub struct Platform { /* private fields */ }Expand description
A plain platform identity value backed by a platform triple.
Implementations
Sourceimpl Platform
impl Platform
Sourcepub const fn new(triple: PlatformTriple) -> Self
pub const fn new(triple: PlatformTriple) -> Self
Creates a platform from an already modeled platform triple.
Sourcepub const fn triple(&self) -> &PlatformTriple
pub const fn triple(&self) -> &PlatformTriple
Returns the platform triple.
Sourcepub fn into_triple(self) -> PlatformTriple
pub fn into_triple(self) -> PlatformTriple
Consumes the platform and returns the platform triple.